@@ -325,4 +325,10 @@ class SQLExport(Sink):
                              }))
                 raise Exception("Error while storing")
 
+    def validate_results(self, what, state):
+        """
+        Check to make sure that the execution completed correctly
+        """
+        pass
+
 provider = SQLExport
