@@ -1144,14 +1144,15 @@ class Node(metaclass=NodeMeta):
 
         """
 
-        customer = self.config.get_customer()
+        usecase = self.config.get_usecase()
 
         metadata = {
             "schema": "standalone:pipeline",
             "version": "1.0",
             'timestamp': datetime.now().replace(microsecond=0).isoformat(),
             'pipeline': {
-                "customer": customer,
+                "customer": usecase,
+                "usecase": usecase,
                 "name":   state.name,
                 "description":   self.config.description,
                 "host":  state.stats['platform']['node'],
@@ -1305,7 +1306,7 @@ class Skin(Node):
     Renders the data computed the transforms and modules.
 
     This is typically used by built-in capabilities such as Search.
-    An alternative to implementing this is to use the customer apps
+    An alternative to implementing this is to use the usecase apps
     capabilities (explained elsewhere)
 
     """
