@@ -861,9 +861,13 @@ class PipelineConfig(object):
             'enrich_data_dir': os.environ['ENRICH_DATA']
         }
 
-        for attr in ['customer_root', 'data_root', 'output']:
+        for attr in ['data_root', 'output']:
             params[attr] = self.spec[attr] % params
 
+        # => handle usecase_root/customer_root carefully for backward compatability
+        usecase_root = self.spec.get('usecase_root',self.spec.get('customer_root', "Unknown"))
+        params['usecase_root'] = params['customer_root'] = usecase_root % params
+
         # Handle aliases
         aliases = {
             'outputdir': 'output',
