@@ -7,6 +7,8 @@ import traceback
 import importlib
 import subprocess
 from datetime import datetime
+from dateutil import parser as dateparser
+from dateutil.tz import tzlocal
 from colored import fg, bg, attr
 
 from .exceptions import *
@@ -162,11 +164,13 @@ def get_credentials_by_type(conditions,app={},context={}):
 
     return final
 
-def update_from_git(detail, context):
+def update_from_git(detail, context,debug=False):
 
     # Make a local version
     context = copy.copy(context)
 
+    label = detail.get('label', detail.get('repo','unknown'))
+
     # Try the detail run root
     root = detail['git'] % context
     if not os.path.exists(root):
@@ -178,15 +182,18 @@ def update_from_git(detail, context):
         # Fallback to the default run_root
         context['ENRICH_RUN_ROOT'] = context['ENRICH_ROOT']
         altroot = detail['git'] % context
-        if not os.path.exists(root):
+        if not os.path.exists(altroot):
             raise Exception("Missing repo roots: {}, {}".format(root, altroot))
         root = altroot
 
     # Update in place
     detail['git'] = root
 
+    # By default use master branch only..
+    branch = detail.get('branch', 'master')
+
     # Collect all the notes
-    cmd = "git -C {} log --pretty='%h--%ci--%N'".format(root)
+    cmd = "git -C {} log {} --pretty='%h--%ci--%N'".format(root, branch)
     notes = subprocess.check_output(cmd, shell=True)
     notes = notes.decode('utf-8')
     notes = notes.split("\n")
@@ -209,8 +216,7 @@ def update_from_git(detail, context):
     detail['branches'] = lines
 
     # Collect the git commits
-    head_tagged = False
-    cmd = """git -C {} log --no-walk --tags --pretty="%h\t%D\t%ce\t%ci\t%s" --decorate=full --date=short""".format(root)
+    cmd = """git -C {} log {} --no-walk --tags --all --pretty="%h\t%D\t%ce\t%ci\t%s" --decorate=full --date=short""".format(root, branch)
     lines = subprocess.check_output(cmd, shell=True)
     lines = lines.decode('utf-8')
     lines = lines.split("\n")
@@ -219,15 +225,45 @@ def update_from_git(detail, context):
     lines = [l for l in lines if len(l) == 5]
     alltags = []
     for l in lines:
+
+        if debug:
+            print(l)
+
+        # Skip all irrelevant remotes except upstream for the given branch
         refs = [x.strip() for x in l[1].split(",")]
-        # Have we seed the head yet?
-        head_tagged = head_tagged or any([ref.startswith('HEAD') for ref in refs])
+
+        # Use relevant records. There is stuff from other branches,
+        valid = False
+        for r in refs:
+            if (('refs/heads/{}'.format(branch) in r) or
+                ('refs/remotes/origin/{}'.format(branch) in r) or
+                ('refs/tags' in r) or
+                ("HEAD" in r)):
+                if debug:
+                    print("Match", r)
+                valid = True
+                break
+
+        if not valid:
+            if debug:
+                print("Skipping")
+            continue
+
+        # Is this head?
+        head = any([ref.startswith('HEAD') for ref in refs])
+
+        # Align the local date
+        try:
+            dt = dateparser.parse(l[3]).astimezone(tzlocal()).isoformat()
+        except:
+            dt = l[3]
+
         entry = {
             #['416366c', 'tag: refs/tags/v1.4.0, refs/heads/master', '2020-03-03', 'pingali@gmail.com', 'Bug']
             'commit': l[0],
             'refs':   refs,
             'author':   l[2],
-            'date': l[3],
+            'date': dt,
             'log':   l[4]
         }
 
@@ -239,26 +275,13 @@ def update_from_git(detail, context):
                 entry['tag'] = tag
                 break
 
-        if 'tag' in entry:
-            alltags.append(entry)
+        if 'tag' not in entry:
+            entry['tag'] = l[0]
 
-    if not head_tagged:
-        # The head that is deployed does not correspond to any of the tags.
-        #e1b93e1 HEAD -> refs/heads/master       pingali@gmail.com 2020-04-19 11:10:57 +0530  Updated documentation
-        cmd = """git -C {} log --no-walk --pretty="%h\t%D\t%ce\t%ci\t%s" --decorate=full --date=short""".format(root)
-        line = subprocess.check_output(cmd, shell=True)
-        line = line.decode('utf-8')
-        line = line.strip().split("\t")
-        refs = [x.strip() for x in line[1].split(",")]
-        alltags.append({
-            'commit': line[0],
-            'refs':   refs,
-            'tag': 'HEAD',
-            'author':   line[2],
-            'date': line[3],
-            'log':   line[4]
-        })
+        if debug:
+            print(entry)
 
+        alltags.append(entry)
 
     # Now sort by reverse commit date
     alltags = sorted(alltags,
@@ -271,6 +294,7 @@ def update_from_git(detail, context):
     for entry in alltags:
 
         head = any([ref.startswith('HEAD') for ref in entry['refs']])
+
         # Where is this position...
         if head:
             entry['position'] = 'head'
@@ -327,7 +351,7 @@ def read_versionmap(filename=None,
         if len(context) == 0:
             context = Context().asdict()
     elif isinstance(context, Context):
-        context = context.asdict() 
+        context = context.asdict()
 
     default = [
         {
@@ -389,6 +413,11 @@ def read_versionmap(filename=None,
     # specified.
     for i in range(len(versionmap)):
 
+        label = versionmap[i].get('label', versionmap[i].get('repo','unknown'))
+
+        if 'branch' not in versionmap[i]:
+            versionmap[i]['branch'] = 'master'
+
         if versionmap[i].get('dynamic', False):
             try:
                 if 'package' not in versionmap[i] and 'git' not in versionmap[i]:
@@ -403,8 +432,9 @@ def read_versionmap(filename=None,
                     update_from_git(versionmap[i], context)
 
             except:
+                traceback.print_exc()
                 versionmap[i]['release'] += " (out of date; import issue)"
-                logger.exception("Unable to import package/repository to update version",
+                logger.exception("{}: Unable to import package/repository to update version".format(label),
                                  extra={
                                      'data': json.dumps(versionmap[i], indent=4)
                                  })
