@@ -598,8 +598,10 @@ def prepare_taskconf(path, templatepath):
         return
 
     validators = {
-        'confname': NameValidator(),
-        'taskname': NameValidator(),
+        'taskdag_name': NameValidator(),
+        'taskdag_name': NameValidator(),
+        'runid_prefix': NameValidator(),
+        'task_name': NameValidator(),
         'description': GenericDescValidator()
     }
 
@@ -609,15 +611,17 @@ def prepare_taskconf(path, templatepath):
     else:
         lib_template = templatepath
 
-    context = {
+    defaults = {
         'customer': conf['org']['customer'],
-        'division': conf['org']['name'],
+        'usecase': conf['org']['name'],
     }
+
+
+    context = {}
     variables = get_variables(lib_template)
     for v in variables:
-        if v in context:
-            continue
         context[v] = prompt('> ' + v +": ",
+                            default=defaults.get(v,""),
                             validator=validators.get(v,None))
     content = render(lib_template, context)
 
@@ -630,7 +634,7 @@ def prepare_taskconf(path, templatepath):
         fd.write(content)
 
     # Bye bye
-    print("Bootstrapped configuration {} in {}".format(context['confname'], path))
+    print("Bootstrapped configuration {} in {}".format(context['taskdag_name'], path))
 
 def prepare_pipelineconf(path, templatepath):
 
@@ -646,12 +650,13 @@ def prepare_pipelineconf(path, templatepath):
         return
 
     validators = {
-        'confname': NameValidator(),
-        'runname': NameValidator(),
-        'email': EmailValidator(),
+        'pipeline_name': NameValidator(),
+        'pipeline_description': GenericDescValidator(),
+        'usecase': NameValidator(),
+        'runid_prefix': NameValidator(),
+        'notification_email': EmailValidator(),
         'transform': NameValidator(),
         'realtime_or_batch': RealtimeBatchValidator(),
-        'description': GenericDescValidator()
     }
 
     print("\nPlease provide configuration details\n")
@@ -665,16 +670,14 @@ def prepare_pipelineconf(path, templatepath):
         lib_template = templatepath
 
     defaults = {
-        'realtime_or_batch': 'batch'
-    }
-    context = {
+        'realtime_or_batch': 'batch',
         'customer': conf.get('org',{}).get('customer',''),
-        'division': conf.get('org',{}).get('name','')
+        'usecase': conf.get('org',{}).get('name','')
     }
+
+    context = {}
     variables = get_variables(lib_template)
     for v in variables:
-        if v in context:
-            continue
         context[v] = prompt('> ' + v +": ",
                             default=defaults.get(v,""),
                             validator=validators.get(v,None))
@@ -1023,7 +1026,6 @@ def populate(context={}):
         "ENRICH_LOGS",
         "ENRICH_CUSTOMERS",
         "ENRICH_RELEASES",
-        "ENRICH_CUSTOMERS",
         "ENRICH_TEST",
     ]
     for var in variables:
@@ -1091,8 +1093,8 @@ def populate(context={}):
             else:
                 for c in customers:
                     for usecase in os.listdir(os.path.join(enrich_customers, c)):
-                        customer_root = os.path.join(enrich_customers, c, usecase)
-                        enrichjson = os.path.join(customer_root, 'enrich.json')
+                        usecase_root = os.path.join(enrich_customers, c, usecase)
+                        enrichjson = os.path.join(usecase_root, 'enrich.json')
                         if not os.path.exists(enrichjson):
                             continue
                         data_root = os.path.join(enrich_data, c, usecase)
@@ -1180,10 +1182,10 @@ def checkenv(validate_only=False,context={}):
         else:
             for c in customers:
                 for usecase in os.listdir(os.path.join(enrich_customers, c)):
-                    customer_root = os.path.join(enrich_customers, c, usecase)
+                    usecase_root = os.path.join(enrich_customers, c, usecase)
                     data_root = os.path.join(enrich_data, c, usecase)
-                    if not (os.path.isdir(customer_root) and
-                            os.path.exists(os.path.join(customer_root,
+                    if not (os.path.isdir(usecase_root) and
+                            os.path.exists(os.path.join(usecase_root,
                                                         'enrich.json'))):
                         continue
                     if not os.path.exists(data_root):
@@ -1523,69 +1525,6 @@ def test_execution_compute(params):
 
     return nextstep
 
-def test_execution_skin(params):
-
-    obj = params['obj']
-    config = params['config']
-    state = config.get_state()
-    pkgdir = params['pkgdir']
-
-    nextstep = True
-
-    try:
-        conf = obj.testdata.get('conf', {})
-        conf['test'] = True
-        obj.configure(conf)
-        print(greenbg('Configured the module'))
-    except:
-        print(redbg('Could not configure the module'))
-        print_exc(params)
-        nextstep = False
-
-    # Run the computation
-    try:
-        options = obj.discover_params()
-        print(greenbg('Executed the discover params function'))
-    except:
-        print(redbg('Could not execute process'))
-        print_exc(params)
-        nextstep = False
-
-    if not nextstep:
-        return nextstep
-
-    # Run the computation
-    try:
-        try:
-            customer_root = obj.testdata['conf']['customer_root']
-            static_paths = obj.testdata['conf']['static_paths']
-            static_paths = [
-                p % {
-                    'customer_root': customer_root
-                } for p in static_paths
-            ]
-        except:
-            traceback.print_exc()
-            static_paths = []
-
-        print(greenbg('Starting the server'))
-        app = create_app({
-            'static_paths': static_paths,
-            'options': options,
-            'skin': obj
-        })
-        try:
-            app.run()
-        except SystemExit:
-            pass
-        print(greenbg('Checked the render'))
-    except:
-        print(redbg('Could not run local server'))
-        print_exc(params)
-        nextstep = False
-
-    if not nextstep:
-        return nextstep
 
 def test_execution(params):
 
@@ -1595,8 +1534,6 @@ def test_execution(params):
 
     if (obj.is_transform() or obj.is_model()):
         return test_execution_compute(params)
-    elif (obj.is_skin() and not obj.is_search()):
-        return test_execution_skin(params)
 
     raise Exception("Unsupported module")
 
@@ -1644,18 +1581,22 @@ def test_conf_pipeline(conf, context):
         'enrich_data_dir': os.environ['ENRICH_DATA']
     }
 
+    usecase_root = conf.get('usecase_root', conf['customer_root'])
     params.update({
-        'customer_root': conf['customer_root'] % params,
+        'usecase_root': usecase_root % params,
+        # Backward compatability
+        'customer_root': usecase_root % params,
         'data_root': conf['data_root'] % params,
     })
 
 
-    for col in ['data_root', 'customer_root']:
+    for col in ['data_root', 'customer_root', 'usecase_root']:
         if not os.path.exists(params[col]):
             print(redbg("{} is missing".format(col)))
 
     config = MockConfig(context)
-    config.load_customer(conf['conf']) # Pass path
+    config.load_usecase(conf['conf']) # Pass path
+    config.load_test_state({})
 
     # Prepare the sys path
     available = []
@@ -1751,7 +1692,8 @@ def test_task_pipeline(conf, context):
     })
 
     config = MockConfig(context)
-    config.load_customer(conf['conf'])
+    config.load_usecase(conf['conf'])
+    config.load_test_state({})
 
     libraries = conf['paths']['libraries']
     for l in libraries:
@@ -1919,7 +1861,7 @@ def test_transform(pkgdir, capture=False, context=None):
 
     # Load the enrich json available...
     try:
-        config.load_customer(pkgdir)
+        config.load_usecase(pkgdir)
     except:
         raise Exception("Unable to load usecase details")
 
@@ -1985,7 +1927,7 @@ def load_transform(pkgdir, capture, context):
 
     # Create a config and load customer
     config = MockConfig(context)
-    config.load_customer(dirname)
+    config.load_usecase(dirname)
 
     params = {
         'pkgdir': dirname,
