@@ -269,36 +269,46 @@ class MockConfig(object):
         self.readonly = False
         self.data_root = self.context['ENRICH_TEST']
         self.customer_root = self.context['ENRICH_CUSTOMERS']
+        self.enrich_customers = self.context['ENRICH_CUSTOMERS']
         self.enrich_root = self.context['ENRICH_ROOT']
         self.enrich_run_root = self.context['ENRICH_ROOT']
         self.enrich_data_dir = self.data_root
         self.accessed_files = []
         self.supported_extra_args = []
-
+        self.usecase = {
+            'org': {
+                'name': 'Unknown',
+                'customer': 'unknown'
+            }
+        }
         # Add defaults
         for attr in ['data_root', 'enrich_data_dir',
                      'inputdir', 'outputdir', 'statedir']:
             setattr(self, attr, self.data_root)
 
 
-    def load_customer(self, path):
+    def get_usecase(self):
+        return self.usecase
 
-        self.customer = {}
+    def get_customer(self):
+        return self.get_usecase()
+
+    def load_usecase(self, path):
 
         enrichjson = None
-        customer_root = self.customer_root
+        enrich_customers = self.enrich_customers
 
         if 'ENRICHJSON' in os.environ:
             enrichjson = os.environ['ENRICHJSON']
             enrichjson = os.path.abspath(enrichjson)
         elif 'ENRICHJSON' in self.context:
             enrichjson = os.path.abspath(self.context['ENRICHJSON'])
-        elif os.path.exists(customer_root):
+        elif os.path.exists(enrich_customers):
             # Try inferring from the location.
             enrichjson = None
             path = os.path.realpath(path)
-            for c in os.listdir(customer_root):
-                c = os.path.realpath(os.path.join(customer_root, c))
+            for c in os.listdir(enrich_customers):
+                c = os.path.realpath(os.path.join(enrich_customers, c))
                 if path.startswith(c):
                     relpath = os.path.relpath(path, start=c)
                     enrichjson = os.path.join(c,
@@ -316,20 +326,11 @@ class MockConfig(object):
         except:
             raise Exception("enrich.json should be valid json file")
 
-        self.customer = enrich
+        self.usecase = enrich
 
     def get_cmdline_args(self):
         return {}
 
-    def get_customer(self):
-
-        customer = "Unknown"
-
-        if 'customer' in self.context:
-            return self.context['customer']
-
-        return self.customer.get("org",{}).get("name","Unknown")
-
     def configure(self, params):
         for var in ['enable_extra_args']:
             if var in params:
