@@ -19,6 +19,7 @@ import click
 from pythonjsonlogger import jsonlogger
 
 # self
+import enrichsdk
 from enrichsdk import package, datasets, api as sdkapi, lib, featurestore as fslib
 
 @click.group()
@@ -28,6 +29,7 @@ def process():
 
     \b
     Getting started:
+       version:  Version of this sdk
        start:    First time instructions
        env:      Setup the environment context
 
@@ -46,6 +48,13 @@ def process():
     """
     pass
 
+@click.command('version', hidden=True)
+def _version():
+    """
+    Show version
+    """
+    print(enrichsdk.__version__)
+
 @click.command('start', hidden=True)
 @click.option('--commands/--no-commands',
               default=False,
@@ -532,7 +541,7 @@ def _testdata_action(ctx, dataset, command):
     """
     Generate action commands for a dataset over a specified range
 
-    Pass additional parameters as key-value pairs as 
+    Pass additional parameters as key-value pairs as
     shown in show.
     """
 
@@ -1215,6 +1224,7 @@ api.add_command(featurestore)
 ###################################
 # Add to process
 ###################################
+process.add_command(_version)
 process.add_command(_start)
 process.add_command(bootstrap_)
 process.add_command(envsetup)
